@@ -16,6 +16,11 @@ package Mail::DKIM::Policy;
 
 Mail::DKIM::Policy - represents a DKIM sender signing policy
 
+=head1 DESCRIPTION
+
+A sender signing policy, according to DKIM, is a record published
+in the message author's DNS that describes how they sign messages.
+
 =head1 CONSTRUCTORS
 
 =head2 fetch() - fetch a sender signing policy from DNS
@@ -146,6 +151,11 @@ sub parse
 
 =head2 apply() - apply the policy to the results of a DKIM verifier
 
+  my $result = $policy->apply($dkim_verifier);
+
+The caller must provide an instance of Mail::DKIM::Verifier, one which
+has already been fed the message being verified.
+
 Possible results are:
 
 =over
@@ -263,7 +273,7 @@ Party Signature SHOULD be accepted.
 
 =back
 
-TODO
+Other values are possible as well, they just haven't been documented yet.
 
 =cut
 
@@ -339,4 +349,16 @@ section 4 of the dkim-ssp Internet Draft.
 
 =back
 
+=head1 AUTHOR
+
+Jason Long, E<lt>jlong@messiah.eduE<gt>
+
+=head1 COPYRIGHT AND LICENSE
+
+Copyright (C) 2006 by Messiah College
+
+This library is free software; you can redistribute it and/or modify
+it under the same terms as Perl itself, either Perl version 5.8.6 or,
+at your option, any later version of Perl 5 you may have available.
+
 =cut
